@@ -470,7 +470,7 @@ module XTemplate
 	when /^dbi:(.+)/
 	  require 'dbi'
 	  h = DBI.connect("dbi:#{$1}")
-	  query = args[1..-1].collect{|s|s.gsub(/\#{(.+)}/){eval_expr($1,val,nil).to_s }}.join(',')
+	  query = args[1..-1].collect{|s|s.gsub(/\#\{(.+)\}/){eval_expr($1,val,nil).to_s }}.join(',')
 	  newval = []
 	  h.execute(query){|sth|
 	    while( r = sth.fetch_hash )
