@@ -1,5 +1,5 @@
 require 'xtemplate'
-$KCODE = "EUC-JP"
+$KCODE = "UTF-8"
 
 template = XTemplate::XMLTemplate.new(<<EOS)
 <xt:template xmlns:xt="http://xtemplate.sourceforge.net/xtemplate">
