@@ -65,6 +65,10 @@ scripts.each{|script|
   if( File.exist?("tmp/samples") )
     File.open("tmp/#{script.gsub(/\.rb$/,'.out')}","w"){|f| f.write($result)}
   end
+  result.strip!
+  result.gsub!(/\r?\n/,"")
+  $result.strip!
+  $result.gsub!(/\r?\n/,"")
   if( result.strip == $result.strip )
     $stdout.print("#{script}: ok")
   else
